@@ -37,12 +37,23 @@ class WorkflowOptions:
     @classmethod
     def from_args(cls, args: t.Any) -> "WorkflowOptions":
         return cls(
-            clean=getattr(args, "clean", False),
-            test=getattr(args, "test", False),
-            publish=getattr(args, "publish", None),
-            bump=getattr(args, "bump", None),
-            commit=getattr(args, "commit", False),
-            create_pr=getattr(args, "create_pr", False),
+            cleaning=CleaningConfig(
+                clean=getattr(args, "clean", False),
+            ),
+            testing=TestConfig(
+                test=getattr(args, "test", False),
+            ),
+            publishing=PublishConfig(
+                publish=getattr(args, "publish", None),
+                bump=getattr(args, "bump", None),
+            ),
+            git=GitConfig(
+                commit=getattr(args, "commit", False),
+                create_pr=getattr(args, "create_pr", False),
+            ),
+            ai=AIConfig(
+                ai_agent=getattr(args, "ai_agent", False),
+            ),
             interactive=getattr(args, "interactive", True),
             dry_run=getattr(args, "dry_run", False),
         )
@@ -311,12 +322,12 @@ class WorkflowManager:
 
     def _handle_task_without_executor(self, task: Task) -> bool:
         task.skip()
-        self.console.print(f"[yellow]⏭️ Skipped {task.name} (no executor)[/yellow]")
+        self.console.print(f"[yellow]⏭️ Skipped {task.name} (no executor)[/ yellow]")
         return True
 
     def _execute_task_with_executor(self, task: Task) -> bool:
         task.start()
-        self.console.print(f"[blue]🔄 Running {task.name}...[/blue]")
+        self.console.print(f"[blue]🔄 Running {task.name}...[/ blue]")
 
         try:
             return self._try_execute_task(task)
@@ -334,9 +345,9 @@ class WorkflowManager:
     def _display_task_result(self, task: Task, success: bool) -> None:
         if success:
             duration_str = f" ({task.duration: .1f}s)" if task.duration else ""
-            self.console.print(f"[green]✅ {task.name}{duration_str}[/green]")
+            self.console.print(f"[green]✅ {task.name}{duration_str}[/ green]")
         else:
-            self.console.print(f"[red]❌ {task.name} failed[/red]")
+            self.console.print(f"[red]❌ {task.name} failed[/ red]")
 
     def _handle_task_exception(self, task: Task, e: Exception) -> bool:
         error = CrackerjackError(
@@ -344,7 +355,7 @@ class WorkflowManager:
             error_code=ErrorCode.COMMAND_EXECUTION_ERROR,
         )
         task.fail(error)
-        self.console.print(f"[red]💥 {task.name} crashed: {e}[/red]")
+        self.console.print(f"[red]💥 {task.name} crashed: {e}[/ red]")
         return False
 
     def display_task_tree(self) -> None:
@@ -587,11 +598,11 @@ class InteractiveCLI:
         )
         self.create_dynamic_workflow(options)
 
-        self.console.print("[bold blue]🚀 Starting Interactive Workflow[/bold blue]")
+        self.console.print("[bold blue]🚀 Starting Interactive Workflow[/ bold blue]")
         self.workflow.display_task_tree()
 
         if not Confirm.ask("Continue with workflow?"):
-            self.console.print("[yellow]Workflow cancelled by user[/yellow]")
+            self.console.print("[yellow]Workflow cancelled by user[/ yellow]")
             return False
 
         return self._execute_workflow_loop()
@@ -626,7 +637,7 @@ class InteractiveCLI:
         ]
 
         if pending_tasks:
-            self.console.print("[red]❌ Workflow stuck - unresolved dependencies[/red]")
+            self.console.print("[red]❌ Workflow stuck-unresolved dependencies[/ red]")
             return False
         return True
 
@@ -645,7 +656,7 @@ class InteractiveCLI:
     def _display_workflow_summary(self) -> None:
         summary = self.workflow.get_workflow_summary()
 
-        self.console.print("\n[bold]📊 Workflow Summary[/bold]")
+        self.console.print("\n[bold]📊 Workflow Summary[/ bold]")
 
         table = Table(show_header=True, header_style="bold magenta")
         table.add_column("Status", style="cyan")
