@@ -5,6 +5,7 @@ import subprocess
 import sys
 import tempfile
 import time
+import typing as t
 from contextlib import suppress
 from pathlib import Path
 
@@ -14,6 +15,8 @@ from textual.containers import Container
 from textual.widget import Widget
 from textual.widgets import DataTable, Footer, Label, ProgressBar
 
+from crackerjack.core.timeout_manager import TimeoutStrategy, get_timeout_manager
+
 from .progress_components import (
     ErrorCollector,
     JobDataCollector,
@@ -24,7 +27,7 @@ from .progress_components import (
 
 
 class AgentStatusPanel(Widget):
-    def __init__(self, **kwargs) -> None:
+    def __init__(self, **kwargs: t.Any) -> None:
         super().__init__(**kwargs)
         self.border_title = "🤖 AI Agents"
         self.border_title_align = "left"
@@ -47,13 +50,13 @@ class AgentStatusPanel(Widget):
 
             agents_table.styles.max_height = "8"
 
-    def update_agent_data(self, agent_data: dict) -> None:
+    def update_agent_data(self, agent_data: dict[str, t.Any]) -> None:
         with suppress(Exception):
             self._update_coordinator_status(agent_data)
             self._update_agents_table(agent_data)
             self._update_stats(agent_data)
 
-    def _update_coordinator_status(self, data: dict) -> None:
+    def _update_coordinator_status(self, data: dict[str, t.Any]) -> None:
         with suppress(Exception):
             activity = data.get("agent_activity", {})
             registry = activity.get("agent_registry", {})
@@ -66,7 +69,7 @@ class AgentStatusPanel(Widget):
                 f"Coordinator: {status_emoji} {coordinator_status.title()} ({total_agents} agents)",
             )
 
-    def _update_agents_table(self, data: dict) -> None:
+    def _update_agents_table(self, data: dict[str, t.Any]) -> None:
         with suppress(Exception):
             agents_table = self.query_one("#agents-table", DataTable)
             agents_table.clear()
@@ -75,7 +78,7 @@ class AgentStatusPanel(Widget):
             active_agents = activity.get("active_agents", [])
 
             if not active_agents:
-                agents_table.add_row("No active agents", " - ", " - ", " - ", " - ")
+                agents_table.add_row("No active agents", "-", "-", "-", "-")
                 return
 
             for agent in active_agents:
@@ -88,9 +91,9 @@ class AgentStatusPanel(Widget):
 
                 current_issue = agent.get("current_issue", {})
                 issue_type = (
-                    current_issue.get("type", " - ")
+                    current_issue.get("type", "-")
                     if current_issue
-                    else agent.get("issue_type", " - ")
+                    else agent.get("issue_type", "-")
                 )
 
                 status_display = f"{self._get_status_emoji(status)} {status.title()}"
@@ -99,11 +102,11 @@ class AgentStatusPanel(Widget):
                     f"{emoji} {agent_type}",
                     status_display,
                     issue_type,
-                    f"{confidence: .0 % }" if confidence > 0 else " - ",
-                    f"{processing_time: .1f}s" if processing_time > 0 else " - ",
+                    f"{confidence: .0 % }" if confidence > 0 else "-",
+                    f"{processing_time: .1f}s" if processing_time > 0 else "-",
                 )
 
-    def _update_stats(self, data: dict) -> None:
+    def _update_stats(self, data: dict[str, t.Any]) -> None:
         with suppress(Exception):
             performance = data.get("agent_performance", {})
             total_issues = performance.get("total_issues_processed", 0)
@@ -150,12 +153,12 @@ class AgentStatusPanel(Widget):
 
 
 class JobPanel(Widget):
-    def __init__(self, job_data: dict, **kwargs) -> None:
+    def __init__(self, job_data: dict[str, t.Any], **kwargs: t.Any) -> None:
         super().__init__(**kwargs)
         self.job_data = job_data
         self.completion_time = None
         self.iteration_count = job_data.get("iteration", 0)
-        self.max_iterations = job_data.get("max_iterations", 10)
+        self.max_iterations = job_data.get("max_iterations", 5)
         self.fade_timer = None
         self.remove_timer = None
         self.fade_level = 0
@@ -212,7 +215,7 @@ class JobPanel(Widget):
             errors_container.border_title = "❌ Errors"
 
             errors_table = self.query_one(
-                f"#job-errors-{self.job_data.get('job_id', 'unknown')}",
+                f"#job-errors -{self.job_data.get('job_id', 'unknown')}",
                 DataTable,
             )
             errors_table.add_columns("", "", "", "")
@@ -222,7 +225,7 @@ class JobPanel(Widget):
     def _update_errors_table(self) -> None:
         with suppress(Exception):
             errors_table = self.query_one(
-                f"#job-errors-{self.job_data.get('job_id', 'unknown')}",
+                f"#job-errors -{self.job_data.get('job_id', 'unknown')}",
                 DataTable,
             )
             errors_table.clear()
@@ -276,7 +279,7 @@ class JobPanel(Widget):
     def _update_progress_bar(self) -> None:
         with suppress(Exception):
             progress_bar = self.query_one(
-                f"#job-progress-{self.job_data.get('job_id', 'unknown')}",
+                f"#job-progress -{self.job_data.get('job_id', 'unknown')}",
                 ProgressBar,
             )
             progress_value = self.iteration_count / max(self.max_iterations, 1) * 100
@@ -365,7 +368,7 @@ class JobPanel(Widget):
             total=100,
             show_eta=False,
             show_percentage=False,
-            id=f"job-progress-{self.job_data.get('job_id', 'unknown')}",
+            id=f"job-progress -{self.job_data.get('job_id', 'unknown')}",
         )
 
     def _compose_stage_and_status(self) -> ComposeResult:
@@ -401,7 +404,7 @@ class JobPanel(Widget):
     def _compose_errors_column(self) -> ComposeResult:
         with Container(classes="job-errors"):
             yield DataTable(
-                id=f"job-errors-{self.job_data.get('job_id', 'unknown')}",
+                id=f"job-errors -{self.job_data.get('job_id', 'unknown')}",
             )
 
 
@@ -418,9 +421,12 @@ class CrackerjackDashboard(App):
         self.progress_dir = Path(tempfile.gettempdir()) / "crackerjack-mcp-progress"
         self.websocket_url = "ws://localhost:8675"
         self.refresh_timer = None
-        self.active_jobs = {}
-        self.completed_jobs_stats = {}
+        self._refresh_counter = 0
+        self.dev = False
+        self.active_jobs: dict[str, t.Any] = {}
+        self.completed_jobs_stats: dict[str, t.Any] = {}
         self.current_polling_method = "File"
+        self.timeout_manager = get_timeout_manager()
 
         self.job_collector = JobDataCollector(self.progress_dir, self.websocket_url)
         self.service_checker = ServiceHealthChecker()
@@ -442,7 +448,7 @@ class CrackerjackDashboard(App):
     def _compose_left_column(self) -> ComposeResult:
         with Container(id="left-column"):
             yield from self._compose_jobs_panel()
-            yield AgentStatusPanel(id="agent-status-panel")
+            yield AgentStatusPanel(id="agent - status-panel")
 
     def _compose_right_column(self) -> ComposeResult:
         with Container(id="right-column"):
@@ -470,7 +476,7 @@ class CrackerjackDashboard(App):
 
     def _compose_discovery_section(self) -> ComposeResult:
         with Container(id="discovery-section"):
-            yield Container(id="job-discovery-container")
+            yield Container(id="job - discovery-container")
 
     def on_mount(self) -> None:
         self._setup_border_titles()
@@ -528,45 +534,107 @@ class CrackerjackDashboard(App):
         self.refresh_timer = self.set_interval(0.5, self._refresh_data)
 
     async def _refresh_data(self) -> None:
-        with suppress(Exception):
-            if hasattr(self, "_refresh_counter"):
+        try:
+            async with self.timeout_manager.timeout_context(
+                "network_operations",
+                timeout=10.0,
+                strategy=TimeoutStrategy.GRACEFUL_DEGRADATION,
+            ):
                 self._refresh_counter += 1
-            else:
-                self._refresh_counter = 0
 
-            if self._refresh_counter % 10 == 0:
-                await self._ensure_services_running()
+                if self._refresh_counter % 20 == 0:
+                    with suppress(Exception):
+                        await self.timeout_manager.with_timeout(
+                            "network_operations",
+                            self._ensure_services_running(),
+                            timeout=5.0,
+                            strategy=TimeoutStrategy.FAIL_FAST,
+                        )
 
-            jobs_data = await self._discover_jobs()
+                jobs_data = await self.timeout_manager.with_timeout(
+                    "network_operations",
+                    self._discover_jobs(),
+                    timeout=3.0,
+                    strategy=TimeoutStrategy.FAIL_FAST,
+                )
 
-            services_data = await self._collect_services_data()
+                services_data = await self.timeout_manager.with_timeout(
+                    "network_operations",
+                    self._collect_services_data(),
+                    timeout=2.0,
+                    strategy=TimeoutStrategy.FAIL_FAST,
+                )
 
-            errors_data = await self._collect_recent_errors()
+                errors_data = await self.timeout_manager.with_timeout(
+                    "file_operations",
+                    self._collect_recent_errors(),
+                    timeout=2.0,
+                    strategy=TimeoutStrategy.FAIL_FAST,
+                )
 
-            if jobs_data["individual_jobs"]:
-                jobs_data["individual_jobs"][0].get("project", "crackerjack")
+                self.query_one("#services-panel").border_title = "🔧 Services"
 
-            self.query_one("#services-panel").border_title = "🔧 Services"
+                self._update_jobs_table(jobs_data)
+                self._update_services_table(services_data)
+                self._update_errors_table(errors_data)
+                self._update_job_panels(jobs_data)
+                self._update_agent_panel(jobs_data)
+                self._update_status_bars(jobs_data)
 
-            self._update_jobs_table(jobs_data)
-            self._update_services_table(services_data)
-            self._update_errors_table(errors_data)
-            self._update_job_panels(jobs_data)
-            self._update_agent_panel(jobs_data)
-            self._update_status_bars(jobs_data)
+        except Exception as e:
+            with suppress(Exception):
+                console = Console()
+                console.print(f"[red]Dashboard refresh error: {e}[/red]")
 
-    async def _discover_jobs(self) -> dict:
-        result = await self.job_collector.discover_jobs()
-        self.current_polling_method = result["method"]
-        return result["data"]
+    async def _discover_jobs(self) -> dict[str, t.Any]:
+        try:
+            result = await self.timeout_manager.with_timeout(
+                "network_operations",
+                self.job_collector.discover_jobs(),
+                timeout=5.0,
+                strategy=TimeoutStrategy.FAIL_FAST,
+            )
+            self.current_polling_method = result["method"]
+            data_result = result["data"]
+            return t.cast(dict[str, t.Any], data_result)
+        except Exception:
+            return {
+                "active": 0,
+                "completed": 0,
+                "failed": 0,
+                "total": 0,
+                "individual_jobs": [],
+                "total_issues": 0,
+                "errors_fixed": 0,
+                "errors_failed": 0,
+                "current_errors": 0,
+            }
 
-    async def _collect_services_data(self) -> list:
-        return await self.service_checker.collect_services_data()
+    async def _collect_services_data(self) -> list[t.Any]:
+        try:
+            services_data = await self.timeout_manager.with_timeout(
+                "network_operations",
+                self.service_checker.collect_services_data(),
+                timeout=3.0,
+                strategy=TimeoutStrategy.FAIL_FAST,
+            )
+            return t.cast(list[t.Any], services_data)
+        except Exception:
+            return [("Services", "🔴 Timeout", "0")]
 
-    async def _collect_recent_errors(self) -> list:
-        return await self.error_collector.collect_recent_errors()
+    async def _collect_recent_errors(self) -> list[t.Any]:
+        try:
+            errors_data = await self.timeout_manager.with_timeout(
+                "file_operations",
+                self.error_collector.collect_recent_errors(),
+                timeout=2.0,
+                strategy=TimeoutStrategy.FAIL_FAST,
+            )
+            return t.cast(list[t.Any], errors_data)
+        except Exception:
+            return []
 
-    def _update_jobs_table(self, jobs_data: dict) -> None:
+    def _update_jobs_table(self, jobs_data: dict[str, t.Any]) -> None:
         with suppress(Exception):
             jobs_table = self.query_one("#jobs-table", DataTable)
             jobs_table.clear()
@@ -608,7 +676,7 @@ class CrackerjackDashboard(App):
                 ],
             )
 
-    def _update_services_table(self, services_data: list) -> None:
+    def _update_services_table(self, services_data: list[t.Any]) -> None:
         with suppress(Exception):
             services_table = self.query_one("#services-table", DataTable)
             services_table.clear()
@@ -632,7 +700,7 @@ class CrackerjackDashboard(App):
                 polling_status += " 🟢"
             services_table.add_row("Polling", polling_status, "")
 
-    def _update_errors_table(self, errors_data: list) -> None:
+    def _update_errors_table(self, errors_data: list[t.Any]) -> None:
         with suppress(Exception):
             errors_table = self.query_one("#errors-table", DataTable)
             errors_table.clear()
@@ -694,9 +762,9 @@ class CrackerjackDashboard(App):
                 ],
             )
 
-    def _update_agent_panel(self, jobs_data: dict) -> None:
+    def _update_agent_panel(self, jobs_data: dict[str, t.Any]) -> None:
         with suppress(Exception):
-            agent_panel = self.query_one("#agent-status-panel", AgentStatusPanel)
+            agent_panel = self.query_one("#agent - status-panel", AgentStatusPanel)
 
             agent_data = {}
             for job in jobs_data.get("individual_jobs", []):
@@ -707,23 +775,23 @@ class CrackerjackDashboard(App):
             if agent_data:
                 agent_panel.update_agent_data(agent_data)
 
-    def _update_job_panels(self, jobs_data: dict) -> None:
+    def _update_job_panels(self, jobs_data: dict[str, t.Any]) -> None:
         with suppress(Exception):
-            container = self.query_one("#job-discovery-container")
+            container = self.query_one("#job - discovery-container")
             current_job_ids = self._get_current_job_ids(jobs_data)
 
             self._remove_obsolete_panels(current_job_ids)
             self._update_or_create_panels(jobs_data, container)
             self._handle_placeholder_visibility(container)
 
-    def _get_current_job_ids(self, jobs_data: dict) -> set:
+    def _get_current_job_ids(self, jobs_data: dict[str, t.Any]) -> set[t.Any]:
         return (
             {job["job_id"] for job in jobs_data["individual_jobs"]}
             if jobs_data["individual_jobs"]
             else set()
         )
 
-    def _remove_obsolete_panels(self, current_job_ids: set) -> None:
+    def _remove_obsolete_panels(self, current_job_ids: set[t.Any]) -> None:
         jobs_to_remove = []
         for job_id, panel in self.active_jobs.items():
             panel_status = panel.job_data.get("status", "").lower()
@@ -738,7 +806,9 @@ class CrackerjackDashboard(App):
             panel = self.active_jobs.pop(job_id)
             panel.remove()
 
-    def _update_or_create_panels(self, jobs_data: dict, container) -> None:
+    def _update_or_create_panels(
+        self, jobs_data: dict[str, t.Any], container: t.Any
+    ) -> None:
         if not jobs_data["individual_jobs"]:
             return
 
@@ -749,7 +819,7 @@ class CrackerjackDashboard(App):
             else:
                 self._create_new_panel(job, container)
 
-    def _update_existing_panel(self, job: dict) -> None:
+    def _update_existing_panel(self, job: dict[str, t.Any]) -> None:
         existing_panel = self.active_jobs[job["job_id"]]
         existing_panel.job_data = job
         existing_panel.iteration_count = job.get("iteration", 0)
@@ -760,7 +830,7 @@ class CrackerjackDashboard(App):
         self._handle_job_completion(existing_panel, job)
         self._update_panel_border(existing_panel)
 
-    def _update_panel_title(self, panel, job: dict) -> None:
+    def _update_panel_title(self, panel: t.Any, job: dict[str, t.Any]) -> None:
         project_name = job.get("project", "crackerjack")
         status = job.get("status", "").lower()
 
@@ -773,38 +843,38 @@ class CrackerjackDashboard(App):
         else:
             panel.border_subtitle = ""
 
-    def _handle_job_completion(self, panel, job: dict) -> None:
+    def _handle_job_completion(self, panel: t.Any, job: dict[str, t.Any]) -> None:
         job_status = job.get("status", "").lower()
         if job_status in ("completed", "failed") and panel.completion_time is None:
             panel.completion_time = time.time()
             panel.fade_timer = panel.set_timer(300.0, panel._start_fade)
             panel.remove_timer = panel.set_timer(1200.0, panel._remove_panel)
 
-    def _update_panel_border(self, panel) -> None:
+    def _update_panel_border(self, panel: t.Any) -> None:
         new_border = panel._calculate_border_style()
         if new_border != panel.border_style:
             panel.border_style = new_border
             panel.refresh()
 
-    def _create_new_panel(self, job: dict, container) -> None:
+    def _create_new_panel(self, job: dict[str, t.Any], container: t.Any) -> None:
         job_panel = JobPanel(job)
         self.active_jobs[job["job_id"]] = job_panel
         container.mount(job_panel)
 
-    def _handle_placeholder_visibility(self, container) -> None:
-        has_placeholder = bool(container.query("#no-jobs-label"))
+    def _handle_placeholder_visibility(self, container: t.Any) -> None:
+        has_placeholder = bool(container.query("#no - jobs-label"))
 
         if not self.active_jobs and not has_placeholder:
             container.mount(
                 Label(
                     "No active jobs detected. Start a Crackerjack job to see progress here.",
-                    id="no-jobs-label",
+                    id="no - jobs-label",
                 ),
             )
         elif self.active_jobs and has_placeholder:
-            container.query("#no-jobs-label").remove()
+            container.query("#no - jobs-label").remove()
 
-    def _update_status_bars(self, jobs_data: dict) -> None:
+    def _update_status_bars(self, jobs_data: dict[str, t.Any]) -> None:
         pass
 
     def action_refresh(self) -> None:
@@ -816,7 +886,7 @@ class CrackerjackDashboard(App):
                 table = self.query_one(table_id, DataTable)
                 table.clear()
 
-            container = self.query_one("#job-discovery-container")
+            container = self.query_one("#job - discovery-container")
             container.query("JobPanel").remove()
             container.query("Label").remove()
             self.active_jobs.clear()
@@ -835,7 +905,7 @@ class CrackerjackDashboard(App):
     def _restore_terminal_fallback(self) -> None:
         self.terminal_restorer.restore_terminal()
 
-    def _signal_handler(self, _signum, _frame) -> None:
+    def _signal_handler(self, _signum: t.Any, _frame: t.Any) -> None:
         with suppress(Exception):
             self._restore_terminal()
             self._cleanup_started_services()
@@ -868,18 +938,18 @@ class JobMetrics:
         self.completion_time: float | None = None
 
         self.iteration = 0
-        self.max_iterations = 10
+        self.max_iterations = 5
         self.current_stage = "Initializing"
         self.status = "running"
         self.message = ""
 
-        self.stages_completed = set()
-        self.stages_failed = set()
+        self.stages_completed: set[str] = set()
+        self.stages_failed: set[str] = set()
 
-        self.errors = []
-        self.warnings = []
-        self.hook_failures = []
-        self.test_failures = []
+        self.errors: list[str] = []
+        self.warnings: list[str] = []
+        self.hook_failures: list[str] = []
+        self.test_failures: list[str] = []
 
 
 async def run_progress_monitor(
@@ -889,14 +959,14 @@ async def run_progress_monitor(
     with suppress(Exception):
         console = Console()
         console.print(
-            "[bold green]🚀 Starting Crackerjack Progress Monitor[/bold green]",
+            "[bold green]🚀 Starting Crackerjack Progress Monitor[/ bold green]",
         )
 
         if enable_watchdog:
-            console.print("[bold yellow]🐕 Service Watchdog: Enabled[/bold yellow]")
+            console.print("[bold yellow]🐕 Service Watchdog: Enabled[/ bold yellow]")
 
         if dev_mode:
-            console.print("[bold cyan]🛠️  Development Mode: Enabled[/bold cyan]")
+            console.print("[bold cyan]🛠️ Development Mode: Enabled[/ bold cyan]")
 
         app = CrackerjackDashboard()
 
@@ -912,7 +982,7 @@ async def run_crackerjack_with_progress(
     with suppress(Exception):
         console = Console()
         console.print(
-            "[bold green]🚀 Starting Crackerjack Progress Monitor[/bold green]",
+            "[bold green]🚀 Starting Crackerjack Progress Monitor[/ bold green]",
         )
 
         app = CrackerjackDashboard()
