@@ -1,5 +1,3 @@
-# !/ usr / bin / env python3
-
 import asyncio
 import json
 import os
@@ -21,8 +19,8 @@ except ImportError:
 
 class AIAgentWorkflowTester:
     def __init__(self) -> None:
-        self.project_root = Path("/Users / les / Projects / crackerjack")
-        self.test_results = {}
+        self.project_root = Path("/ Users / les / Projects / crackerjack")
+        self.test_results: dict[str, str] = {}
         self.verification_toolkit = None
 
         if VERIFICATION_AVAILABLE:
@@ -34,13 +32,13 @@ class AIAgentWorkflowTester:
             "git_status": self._get_git_status(),
             "test_status": self._run_quick_test_check(),
             "hook_status": self._run_quick_hook_check(),
-            "python_files": list(self.project_root.glob(" **/* .py")),
+            "python_files": list(self.project_root.glob(" **/ * .py")),
         }
 
     def _get_git_status(self) -> dict[str, list[str]]:
         try:
             result = subprocess.run(
-                ["git", "status", " -- porcelain"],
+                ["git", "status", " - - porcelain"],
                 check=False,
                 cwd=self.project_root,
                 capture_output=True,
@@ -76,7 +74,7 @@ class AIAgentWorkflowTester:
     def _run_quick_test_check(self) -> dict[str, Any]:
         try:
             result = subprocess.run(
-                ["python", " - m", "pytest", " -- tb = no", " - q"],
+                ["python", " - m", "pytest", " - - tb = no", " - q"],
                 check=False,
                 cwd=self.project_root,
                 capture_output=True,
@@ -103,8 +101,8 @@ class AIAgentWorkflowTester:
                     "python",
                     " - m",
                     "crackerjack",
-                    " -- skip - comprehensive",
-                    " -- skip - tests",
+                    " - - skip - comprehensive",
+                    " - - skip - tests",
                 ],
                 check=False,
                 cwd=self.project_root,
@@ -137,9 +135,9 @@ class AIAgentWorkflowTester:
                     "python",
                     " - m",
                     "crackerjack",
-                    " -- ai - agent",
+                    " - - ai - agent",
                     " - t",
-                    " -- verbose",
+                    " - - verbose",
                 ],
                 check=False,
                 cwd=self.project_root,
@@ -171,9 +169,9 @@ class AIAgentWorkflowTester:
                     "python",
                     " - m",
                     "crackerjack",
-                    " -- ai - agent",
+                    " - - ai - agent",
                     " - t",
-                    " -- verbose",
+                    " - - verbose",
                 ],
                 check=False,
                 cwd=self.project_root,
@@ -211,7 +209,7 @@ class AIAgentWorkflowTester:
             }
 
     def _parse_iterations_from_output(self, output: str) -> list[dict[str, Any]]:
-        iterations = []
+        iterations: list[dict[str, Any]] = []
         lines = output.split("\n")
         current_iteration = None
 
@@ -271,7 +269,9 @@ class AIAgentWorkflowTester:
         try:
             import re
 
-            match = re.search(r"(\d+)\s+fixes?\s+applied", line.lower())
+            match = re.search(
+                r"(\d +)\s + fixes?\s + applied", line.lower()
+            )  # REGEX OK: parsing test output format
             if match:
                 current_iteration["errors_fixed"] += int(match.group(1))
         except (ValueError, AttributeError, ImportError):
@@ -310,7 +310,7 @@ class AIAgentWorkflowTester:
                 cwd=self.project_root,
                 capture_output=True,
                 text=True,
-                timeout=120,
+                timeout=300,  # Fixed: Use 300s to match pytest config
             )
 
             return {
@@ -418,7 +418,7 @@ class AIAgentWorkflowTester:
 
         all_criteria_met = True
         for criterion, met in criteria:
-            status = "✅ PASS" if met else "❌ FAIL"
+            status: str = "✅ PASS" if met else "❌ FAIL"
             report.append(f"{status} {criterion}")
             if not met:
                 all_criteria_met = False
